Crate can_adapter

Crate can_adapter 

Modules

connection
j1939
packet
pushbus
sim
slcan
socketcanconnection
uds

Structs

CanCan
Simple CAN tool for sending and receiving CAN packets over various adapters. This struct
CanContext
Context for CAN operations. Used to pass around the CAN connection and options.

Enums

ConnectionDescriptor
Describes a connection to a CAN bus. Is used by client applications to connect to a CAN bus.

Functions

list_all
List all available connection types and exit.
main
Main entry point for the example command line application.